# coding: utf-8

"""
    Strava API v3

    Strava API  # noqa: E501

    OpenAPI spec version: 3.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from swagger_client.models.activity_type import ActivityType  # noqa: F401,E501


class UpdatableActivity(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'commute': 'bool',
        'trainer': 'bool',
        'description': 'str',
        'name': 'str',
        'type': 'ActivityType',
        'gear_id': 'str'
    }

    attribute_map = {
        'commute': 'commute',
        'trainer': 'trainer',
        'description': 'description',
        'name': 'name',
        'type': 'type',
        'gear_id': 'gear_id'
    }

    def __init__(self, commute=None, trainer=None, description=None, name=None, type=None, gear_id=None):  # noqa: E501
        """UpdatableActivity - a model defined in Swagger"""  # noqa: E501

        self._commute = None
        self._trainer = None
        self._description = None
        self._name = None
        self._type = None
        self._gear_id = None
        self.discriminator = None

        if commute is not None:
            self.commute = commute
        if trainer is not None:
            self.trainer = trainer
        if description is not None:
            self.description = description
        if name is not None:
            self.name = name
        if type is not None:
            self.type = type
        if gear_id is not None:
            self.gear_id = gear_id

    @property
    def commute(self):
        """Gets the commute of this UpdatableActivity.  # noqa: E501

        Whether this activity is a commute  # noqa: E501

        :return: The commute of this UpdatableActivity.  # noqa: E501
        :rtype: bool
        """
        return self._commute

    @commute.setter
    def commute(self, commute):
        """Sets the commute of this UpdatableActivity.

        Whether this activity is a commute  # noqa: E501

        :param commute: The commute of this UpdatableActivity.  # noqa: E501
        :type: bool
        """

        self._commute = commute

    @property
    def trainer(self):
        """Gets the trainer of this UpdatableActivity.  # noqa: E501

        Whether this activity was recorded on a training machine  # noqa: E501

        :return: The trainer of this UpdatableActivity.  # noqa: E501
        :rtype: bool
        """
        return self._trainer

    @trainer.setter
    def trainer(self, trainer):
        """Sets the trainer of this UpdatableActivity.

        Whether this activity was recorded on a training machine  # noqa: E501

        :param trainer: The trainer of this UpdatableActivity.  # noqa: E501
        :type: bool
        """

        self._trainer = trainer

    @property
    def description(self):
        """Gets the description of this UpdatableActivity.  # noqa: E501

        The description of the activity  # noqa: E501

        :return: The description of this UpdatableActivity.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this UpdatableActivity.

        The description of the activity  # noqa: E501

        :param description: The description of this UpdatableActivity.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def name(self):
        """Gets the name of this UpdatableActivity.  # noqa: E501

        The name of the activity  # noqa: E501

        :return: The name of this UpdatableActivity.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this UpdatableActivity.

        The name of the activity  # noqa: E501

        :param name: The name of this UpdatableActivity.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def type(self):
        """Gets the type of this UpdatableActivity.  # noqa: E501


        :return: The type of this UpdatableActivity.  # noqa: E501
        :rtype: ActivityType
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this UpdatableActivity.


        :param type: The type of this UpdatableActivity.  # noqa: E501
        :type: ActivityType
        """

        self._type = type

    @property
    def gear_id(self):
        """Gets the gear_id of this UpdatableActivity.  # noqa: E501

        Identifier for the gear associated with the activity. ‘none’ clears gear from activity  # noqa: E501

        :return: The gear_id of this UpdatableActivity.  # noqa: E501
        :rtype: str
        """
        return self._gear_id

    @gear_id.setter
    def gear_id(self, gear_id):
        """Sets the gear_id of this UpdatableActivity.

        Identifier for the gear associated with the activity. ‘none’ clears gear from activity  # noqa: E501

        :param gear_id: The gear_id of this UpdatableActivity.  # noqa: E501
        :type: str
        """

        self._gear_id = gear_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(UpdatableActivity, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UpdatableActivity):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Strava API v3

    Strava API  # noqa: E501

    OpenAPI spec version: 3.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from swagger_client.api_client import ApiClient


class UploadsApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def create_upload(self, **kwargs):  # noqa: E501
        """Upload Activity  # noqa: E501

        Uploads a new data file to create an activity from. Requires activity:write scope.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_upload(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param file file: The uploaded file.
        :param str name: The desired name of the resulting activity.
        :param str description: The desired description of the resulting activity.
        :param str trainer: Whether the resulting activity should be marked as having been performed on a trainer.
        :param str commute: Whether the resulting activity should be tagged as a commute.
        :param str data_type: The format of the uploaded file.
        :param str external_id: The desired external identifier of the resulting activity.
        :return: Upload
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.create_upload_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.create_upload_with_http_info(**kwargs)  # noqa: E501
            return data

    def create_upload_with_http_info(self, **kwargs):  # noqa: E501
        """Upload Activity  # noqa: E501

        Uploads a new data file to create an activity from. Requires activity:write scope.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_upload_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param file file: The uploaded file.
        :param str name: The desired name of the resulting activity.
        :param str description: The desired description of the resulting activity.
        :param str trainer: Whether the resulting activity should be marked as having been performed on a trainer.
        :param str commute: Whether the resulting activity should be tagged as a commute.
        :param str data_type: The format of the uploaded file.
        :param str external_id: The desired external identifier of the resulting activity.
        :return: Upload
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['file', 'name', 'description', 'trainer', 'commute', 'data_type', 'external_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_upload" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}
        if 'file' in params:
            local_var_files['file'] = params['file']  # noqa: E501
        if 'name' in params:
            form_params.append(('name', params['name']))  # noqa: E501
        if 'description' in params:
            form_params.append(('description', params['description']))  # noqa: E501
        if 'trainer' in params:
            form_params.append(('trainer', params['trainer']))  # noqa: E501
        if 'commute' in params:
            form_params.append(('commute', params['commute']))  # noqa: E501
        if 'data_type' in params:
            form_params.append(('data_type', params['data_type']))  # noqa: E501
        if 'external_id' in params:
            form_params.append(('external_id', params['external_id']))  # noqa: E501

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['multipart/form-data'])  # noqa: E501

        # Authentication setting
        auth_settings = ['strava_oauth']  # noqa: E501

        return self.api_client.call_api(
            '/uploads', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Upload',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_upload_by_id(self, upload_id, **kwargs):  # noqa: E501
        """Get Upload  # noqa: E501

        Returns an upload for a given identifier. Requires activity:write scope.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_upload_by_id(upload_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int upload_id: The identifier of the upload. (required)
        :return: Upload
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_upload_by_id_with_http_info(upload_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_upload_by_id_with_http_info(upload_id, **kwargs)  # noqa: E501
            return data

    def get_upload_by_id_with_http_info(self, upload_id, **kwargs):  # noqa: E501
        """Get Upload  # noqa: E501

        Returns an upload for a given identifier. Requires activity:write scope.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_upload_by_id_with_http_info(upload_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int upload_id: The identifier of the upload. (required)
        :return: Upload
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['upload_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_upload_by_id" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'upload_id' is set
        if ('upload_id' not in params or
                params['upload_id'] is None):
            raise ValueError("Missing the required parameter `upload_id` when calling `get_upload_by_id`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'upload_id' in params:
            path_params['uploadId'] = params['upload_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['strava_oauth']  # noqa: E501

        return self.api_client.call_api(
            '/uploads/{uploadId}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Upload',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Strava API v3

    Strava API  # noqa: E501

    OpenAPI spec version: 3.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class Split(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'average_speed': 'float',
        'distance': 'float',
        'elapsed_time': 'int',
        'elevation_difference': 'float',
        'pace_zone': 'int',
        'moving_time': 'int',
        'split': 'int'
    }

    attribute_map = {
        'average_speed': 'average_speed',
        'distance': 'distance',
        'elapsed_time': 'elapsed_time',
        'elevation_difference': 'elevation_difference',
        'pace_zone': 'pace_zone',
        'moving_time': 'moving_time',
        'split': 'split'
    }

    def __init__(self, average_speed=None, distance=None, elapsed_time=None, elevation_difference=None, pace_zone=None, moving_time=None, split=None):  # noqa: E501
        """Split - a model defined in Swagger"""  # noqa: E501

        self._average_speed = None
        self._distance = None
        self._elapsed_time = None
        self._elevation_difference = None
        self._pace_zone = None
        self._moving_time = None
        self._split = None
        self.discriminator = None

        if average_speed is not None:
            self.average_speed = average_speed
        if distance is not None:
            self.distance = distance
        if elapsed_time is not None:
            self.elapsed_time = elapsed_time
        if elevation_difference is not None:
            self.elevation_difference = elevation_difference
        if pace_zone is not None:
            self.pace_zone = pace_zone
        if moving_time is not None:
            self.moving_time = moving_time
        if split is not None:
            self.split = split

    @property
    def average_speed(self):
        """Gets the average_speed of this Split.  # noqa: E501

        The average speed of this split, in meters per second  # noqa: E501

        :return: The average_speed of this Split.  # noqa: E501
        :rtype: float
        """
        return self._average_speed

    @average_speed.setter
    def average_speed(self, average_speed):
        """Sets the average_speed of this Split.

        The average speed of this split, in meters per second  # noqa: E501

        :param average_speed: The average_speed of this Split.  # noqa: E501
        :type: float
        """

        self._average_speed = average_speed

    @property
    def distance(self):
        """Gets the distance of this Split.  # noqa: E501

        The distance of this split, in meters  # noqa: E501

        :return: The distance of this Split.  # noqa: E501
        :rtype: float
        """
        return self._distance

    @distance.setter
    def distance(self, distance):
        """Sets the distance of this Split.

        The distance of this split, in meters  # noqa: E501

        :param distance: The distance of this Split.  # noqa: E501
        :type: float
        """

        self._distance = distance

    @property
    def elapsed_time(self):
        """Gets the elapsed_time of this Split.  # noqa: E501

        The elapsed time of this split, in seconds  # noqa: E501

        :return: The elapsed_time of this Split.  # noqa: E501
        :rtype: int
        """
        return self._elapsed_time

    @elapsed_time.setter
    def elapsed_time(self, elapsed_time):
        """Sets the elapsed_time of this Split.

        The elapsed time of this split, in seconds  # noqa: E501

        :param elapsed_time: The elapsed_time of this Split.  # noqa: E501
        :type: int
        """

        self._elapsed_time = elapsed_time

    @property
    def elevation_difference(self):
        """Gets the elevation_difference of this Split.  # noqa: E501

        The elevation difference of this split, in meters  # noqa: E501

        :return: The elevation_difference of this Split.  # noqa: E501
        :rtype: float
        """
        return self._elevation_difference

    @elevation_difference.setter
    def elevation_difference(self, elevation_difference):
        """Sets the elevation_difference of this Split.

        The elevation difference of this split, in meters  # noqa: E501

        :param elevation_difference: The elevation_difference of this Split.  # noqa: E501
        :type: float
        """

        self._elevation_difference = elevation_difference

    @property
    def pace_zone(self):
        """Gets the pace_zone of this Split.  # noqa: E501

        The pacing zone of this split  # noqa: E501

        :return: The pace_zone of this Split.  # noqa: E501
        :rtype: int
        """
        return self._pace_zone

    @pace_zone.setter
    def pace_zone(self, pace_zone):
        """Sets the pace_zone of this Split.

        The pacing zone of this split  # noqa: E501

        :param pace_zone: The pace_zone of this Split.  # noqa: E501
        :type: int
        """

        self._pace_zone = pace_zone

    @property
    def moving_time(self):
        """Gets the moving_time of this Split.  # noqa: E501

        The moving time of this split, in seconds  # noqa: E501

        :return: The moving_time of this Split.  # noqa: E501
        :rtype: int
        """
        return self._moving_time

    @moving_time.setter
    def moving_time(self, moving_time):
        """Sets the moving_time of this Split.

        The moving time of this split, in seconds  # noqa: E501

        :param moving_time: The moving_time of this Split.  # noqa: E501
        :type: int
        """

        self._moving_time = moving_time

    @property
    def split(self):
        """Gets the split of this Split.  # noqa: E501

        N/A  # noqa: E501

        :return: The split of this Split.  # noqa: E501
        :rtype: int
        """
        return self._split

    @split.setter
    def split(self, split):
        """Sets the split of this Split.

        N/A  # noqa: E501

        :param split: The split of this Split.  # noqa: E501
        :type: int
        """

        self._split = split

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Split, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Split):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Strava API v3

    Strava API  # noqa: E501

    OpenAPI spec version: 3.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from swagger_client.models.meta_activity import MetaActivity  # noqa: F401,E501
from swagger_client.models.meta_athlete import MetaAthlete  # noqa: F401,E501


class Lap(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'int',
        'activity': 'MetaActivity',
        'athlete': 'MetaAthlete',
        'average_cadence': 'float',
        'average_speed': 'float',
        'distance': 'float',
        'elapsed_time': 'int',
        'start_index': 'int',
        'end_index': 'int',
        'lap_index': 'int',
        'max_speed': 'float',
        'moving_time': 'int',
        'name': 'str',
        'pace_zone': 'int',
        'split': 'int',
        'start_date': 'datetime',
        'start_date_local': 'datetime',
        'total_elevation_gain': 'float'
    }

    attribute_map = {
        'id': 'id',
        'activity': 'activity',
        'athlete': 'athlete',
        'average_cadence': 'average_cadence',
        'average_speed': 'average_speed',
        'distance': 'distance',
        'elapsed_time': 'elapsed_time',
        'start_index': 'start_index',
        'end_index': 'end_index',
        'lap_index': 'lap_index',
        'max_speed': 'max_speed',
        'moving_time': 'moving_time',
        'name': 'name',
        'pace_zone': 'pace_zone',
        'split': 'split',
        'start_date': 'start_date',
        'start_date_local': 'start_date_local',
        'total_elevation_gain': 'total_elevation_gain'
    }

    def __init__(self, id=None, activity=None, athlete=None, average_cadence=None, average_speed=None, distance=None, elapsed_time=None, start_index=None, end_index=None, lap_index=None, max_speed=None, moving_time=None, name=None, pace_zone=None, split=None, start_date=None, start_date_local=None, total_elevation_gain=None):  # noqa: E501
        """Lap - a model defined in Swagger"""  # noqa: E501

        self._id = None
        self._activity = None
        self._athlete = None
        self._average_cadence = None
        self._average_speed = None
        self._distance = None
        self._elapsed_time = None
        self._start_index = None
        self._end_index = None
        self._lap_index = None
        self._max_speed = None
        self._moving_time = None
        self._name = None
        self._pace_zone = None
        self._split = None
        self._start_date = None
        self._start_date_local = None
        self._total_elevation_gain = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if activity is not None:
            self.activity = activity
        if athlete is not None:
            self.athlete = athlete
        if average_cadence is not None:
            self.average_cadence = average_cadence
        if average_speed is not None:
            self.average_speed = average_speed
        if distance is not None:
            self.distance = distance
        if elapsed_time is not None:
            self.elapsed_time = elapsed_time
        if start_index is not None:
            self.start_index = start_index
        if end_index is not None:
            self.end_index = end_index
        if lap_index is not None:
            self.lap_index = lap_index
        if max_speed is not None:
            self.max_speed = max_speed
        if moving_time is not None:
            self.moving_time = moving_time
        if name is not None:
            self.name = name
        if pace_zone is not None:
            self.pace_zone = pace_zone
        if split is not None:
            self.split = split
        if start_date is not None:
            self.start_date = start_date
        if start_date_local is not None:
            self.start_date_local = start_date_local
        if total_elevation_gain is not None:
            self.total_elevation_gain = total_elevation_gain

    @property
    def id(self):
        """Gets the id of this Lap.  # noqa: E501

        The unique identifier of this lap  # noqa: E501

        :return: The id of this Lap.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this Lap.

        The unique identifier of this lap  # noqa: E501

        :param id: The id of this Lap.  # noqa: E501
        :type: int
        """

        self._id = id

    @property
    def activity(self):
        """Gets the activity of this Lap.  # noqa: E501


        :return: The activity of this Lap.  # noqa: E501
        :rtype: MetaActivity
        """
        return self._activity

    @activity.setter
    def activity(self, activity):
        """Sets the activity of this Lap.


        :param activity: The activity of this Lap.  # noqa: E501
        :type: MetaActivity
        """

        self._activity = activity

    @property
    def athlete(self):
        """Gets the athlete of this Lap.  # noqa: E501


        :return: The athlete of this Lap.  # noqa: E501
        :rtype: MetaAthlete
        """
        return self._athlete

    @athlete.setter
    def athlete(self, athlete):
        """Sets the athlete of this Lap.


        :param athlete: The athlete of this Lap.  # noqa: E501
        :type: MetaAthlete
        """

        self._athlete = athlete

    @property
    def average_cadence(self):
        """Gets the average_cadence of this Lap.  # noqa: E501

        The lap's average cadence  # noqa: E501

        :return: The average_cadence of this Lap.  # noqa: E501
        :rtype: float
        """
        return self._average_cadence

    @average_cadence.setter
    def average_cadence(self, average_cadence):
        """Sets the average_cadence of this Lap.

        The lap's average cadence  # noqa: E501

        :param average_cadence: The average_cadence of this Lap.  # noqa: E501
        :type: float
        """

        self._average_cadence = average_cadence

    @property
    def average_speed(self):
        """Gets the average_speed of this Lap.  # noqa: E501

        The lap's average speed  # noqa: E501

        :return: The average_speed of this Lap.  # noqa: E501
        :rtype: float
        """
        return self._average_speed

    @average_speed.setter
    def average_speed(self, average_speed):
        """Sets the average_speed of this Lap.

        The lap's average speed  # noqa: E501

        :param average_speed: The average_speed of this Lap.  # noqa: E501
        :type: float
        """

        self._average_speed = average_speed

    @property
    def distance(self):
        """Gets the distance of this Lap.  # noqa: E501

        The lap's distance, in meters  # noqa: E501

        :return: The distance of this Lap.  # noqa: E501
        :rtype: float
        """
        return self._distance

    @distance.setter
    def distance(self, distance):
        """Sets the distance of this Lap.

        The lap's distance, in meters  # noqa: E501

        :param distance: The distance of this Lap.  # noqa: E501
        :type: float
        """

        self._distance = distance

    @property
    def elapsed_time(self):
        """Gets the elapsed_time of this Lap.  # noqa: E501

        The lap's elapsed time, in seconds  # noqa: E501

        :return: The elapsed_time of this Lap.  # noqa: E501
        :rtype: int
        """
        return self._elapsed_time

    @elapsed_time.setter
    def elapsed_time(self, elapsed_time):
        """Sets the elapsed_time of this Lap.

        The lap's elapsed time, in seconds  # noqa: E501

        :param elapsed_time: The elapsed_time of this Lap.  # noqa: E501
        :type: int
        """

        self._elapsed_time = elapsed_time

    @property
    def start_index(self):
        """Gets the start_index of this Lap.  # noqa: E501

        The start index of this effort in its activity's stream  # noqa: E501

        :return: The start_index of this Lap.  # noqa: E501
        :rtype: int
        """
        return self._start_index

    @start_index.setter
    def start_index(self, start_index):
        """Sets the start_index of this Lap.

        The start index of this effort in its activity's stream  # noqa: E501

        :param start_index: The start_index of this Lap.  # noqa: E501
        :type: int
        """

        self._start_index = start_index

    @property
    def end_index(self):
        """Gets the end_index of this Lap.  # noqa: E501

        The end index of this effort in its activity's stream  # noqa: E501

        :return: The end_index of this Lap.  # noqa: E501
        :rtype: int
        """
        return self._end_index

    @end_index.setter
    def end_index(self, end_index):
        """Sets the end_index of this Lap.

        The end index of this effort in its activity's stream  # noqa: E501

        :param end_index: The end_index of this Lap.  # noqa: E501
        :type: int
        """

        self._end_index = end_index

    @property
    def lap_index(self):
        """Gets the lap_index of this Lap.  # noqa: E501

        The index of this lap in the activity it belongs to  # noqa: E501

        :return: The lap_index of this Lap.  # noqa: E501
        :rtype: int
        """
        return self._lap_index

    @lap_index.setter
    def lap_index(self, lap_index):
        """Sets the lap_index of this Lap.

        The index of this lap in the activity it belongs to  # noqa: E501

        :param lap_index: The lap_index of this Lap.  # noqa: E501
        :type: int
        """

        self._lap_index = lap_index

    @property
    def max_speed(self):
        """Gets the max_speed of this Lap.  # noqa: E501

        The maximum speed of this lat, in meters per second  # noqa: E501

        :return: The max_speed of this Lap.  # noqa: E501
        :rtype: float
        """
        return self._max_speed

    @max_speed.setter
    def max_speed(self, max_speed):
        """Sets the max_speed of this Lap.

        The maximum speed of this lat, in meters per second  # noqa: E501

        :param max_speed: The max_speed of this Lap.  # noqa: E501
        :type: float
        """

        self._max_speed = max_speed

    @property
    def moving_time(self):
        """Gets the moving_time of this Lap.  # noqa: E501

        The lap's moving time, in seconds  # noqa: E501

        :return: The moving_time of this Lap.  # noqa: E501
        :rtype: int
        """
        return self._moving_time

    @moving_time.setter
    def moving_time(self, moving_time):
        """Sets the moving_time of this Lap.

        The lap's moving time, in seconds  # noqa: E501

        :param moving_time: The moving_time of this Lap.  # noqa: E501
        :type: int
        """

        self._moving_time = moving_time

    @property
    def name(self):
        """Gets the name of this Lap.  # noqa: E501

        The name of the lap  # noqa: E501

        :return: The name of this Lap.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this Lap.

        The name of the lap  # noqa: E501

        :param name: The name of this Lap.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def pace_zone(self):
        """Gets the pace_zone of this Lap.  # noqa: E501

        The athlete's pace zone during this lap  # noqa: E501

        :return: The pace_zone of this Lap.  # noqa: E501
        :rtype: int
        """
        return self._pace_zone

    @pace_zone.setter
    def pace_zone(self, pace_zone):
        """Sets the pace_zone of this Lap.

        The athlete's pace zone during this lap  # noqa: E501

        :param pace_zone: The pace_zone of this Lap.  # noqa: E501
        :type: int
        """

        self._pace_zone = pace_zone

    @property
    def split(self):
        """Gets the split of this Lap.  # noqa: E501


        :return: The split of this Lap.  # noqa: E501
        :rtype: int
        """
        return self._split

    @split.setter
    def split(self, split):
        """Sets the split of this Lap.


        :param split: The split of this Lap.  # noqa: E501
        :type: int
        """

        self._split = split

    @property
    def start_date(self):
        """Gets the start_date of this Lap.  # noqa: E501

        The time at which the lap was started.  # noqa: E501

        :return: The start_date of this Lap.  # noqa: E501
        :rtype: datetime
        """
        return self._start_date

    @start_date.setter
    def start_date(self, start_date):
        """Sets the start_date of this Lap.

        The time at which the lap was started.  # noqa: E501

        :param start_date: The start_date of this Lap.  # noqa: E501
        :type: datetime
        """

        self._start_date = start_date

    @property
    def start_date_local(self):
        """Gets the start_date_local of this Lap.  # noqa: E501

        The time at which the lap was started in the local timezone.  # noqa: E501

        :return: The start_date_local of this Lap.  # noqa: E501
        :rtype: datetime
        """
        return self._start_date_local

    @start_date_local.setter
    def start_date_local(self, start_date_local):
        """Sets the start_date_local of this Lap.

        The time at which the lap was started in the local timezone.  # noqa: E501

        :param start_date_local: The start_date_local of this Lap.  # noqa: E501
        :type: datetime
        """

        self._start_date_local = start_date_local

    @property
    def total_elevation_gain(self):
        """Gets the total_elevation_gain of this Lap.  # noqa: E501

        The elevation gain of this lap, in meters  # noqa: E501

        :return: The total_elevation_gain of this Lap.  # noqa: E501
        :rtype: float
        """
        return self._total_elevation_gain

    @total_elevation_gain.setter
    def total_elevation_gain(self, total_elevation_gain):
        """Sets the total_elevation_gain of this Lap.

        The elevation gain of this lap, in meters  # noqa: E501

        :param total_elevation_gain: The total_elevation_gain of this Lap.  # noqa: E501
        :type: float
        """

        self._total_elevation_gain = total_elevation_gain

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Lap, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Lap):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Strava API v3

    Strava API  # noqa: E501

    OpenAPI spec version: 3.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from swagger_client.models.zone_range import ZoneRange  # noqa: F401,E501


class TimedZoneRange(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'min': 'int',
        'max': 'int',
        'time': 'int'
    }

    attribute_map = {
        'min': 'min',
        'max': 'max',
        'time': 'time'
    }

    def __init__(self, min=None, max=None, time=None):  # noqa: E501
        """TimedZoneRange - a model defined in Swagger"""  # noqa: E501

        self._min = None
        self._max = None
        self._time = None
        self.discriminator = None

        if min is not None:
            self.min = min
        if max is not None:
            self.max = max
        if time is not None:
            self.time = time

    @property
    def min(self):
        """Gets the min of this TimedZoneRange.  # noqa: E501

        The minimum value in the range.  # noqa: E501

        :return: The min of this TimedZoneRange.  # noqa: E501
        :rtype: int
        """
        return self._min

    @min.setter
    def min(self, min):
        """Sets the min of this TimedZoneRange.

        The minimum value in the range.  # noqa: E501

        :param min: The min of this TimedZoneRange.  # noqa: E501
        :type: int
        """

        self._min = min

    @property
    def max(self):
        """Gets the max of this TimedZoneRange.  # noqa: E501

        The maximum value in the range.  # noqa: E501

        :return: The max of this TimedZoneRange.  # noqa: E501
        :rtype: int
        """
        return self._max

    @max.setter
    def max(self, max):
        """Sets the max of this TimedZoneRange.

        The maximum value in the range.  # noqa: E501

        :param max: The max of this TimedZoneRange.  # noqa: E501
        :type: int
        """

        self._max = max

    @property
    def time(self):
        """Gets the time of this TimedZoneRange.  # noqa: E501

        The number of seconds spent in this zone  # noqa: E501

        :return: The time of this TimedZoneRange.  # noqa: E501
        :rtype: int
        """
        return self._time

    @time.setter
    def time(self, time):
        """Sets the time of this TimedZoneRange.

        The number of seconds spent in this zone  # noqa: E501

        :param time: The time of this TimedZoneRange.  # noqa: E501
        :type: int
        """

        self._time = time

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(TimedZoneRange, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, TimedZoneRange):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

# flake8: noqa

"""
    Strava API v3

    Strava API  # noqa: E501

    OpenAPI spec version: 3.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

# import apis into sdk package
from swagger_client.api.activities_api import ActivitiesApi
from swagger_client.api.athletes_api import AthletesApi
from swagger_client.api.clubs_api import ClubsApi
from swagger_client.api.gears_api import GearsApi
from swagger_client.api.routes_api import RoutesApi
from swagger_client.api.running_races_api import RunningRacesApi
from swagger_client.api.segment_efforts_api import SegmentEffortsApi
from swagger_client.api.segments_api import SegmentsApi
from swagger_client.api.streams_api import StreamsApi
from swagger_client.api.uploads_api import UploadsApi

# import ApiClient
from swagger_client.api_client import ApiClient
from swagger_client.configuration import Configuration
# import models into sdk package
from swagger_client.models.activity_stats import ActivityStats
from swagger_client.models.activity_total import ActivityTotal
from swagger_client.models.activity_type import ActivityType
from swagger_client.models.activity_zone import ActivityZone
from swagger_client.models.base_stream import BaseStream
from swagger_client.models.comment import Comment
from swagger_client.models.error import Error
from swagger_client.models.explorer_response import ExplorerResponse
from swagger_client.models.explorer_segment import ExplorerSegment
from swagger_client.models.fault import Fault
from swagger_client.models.heart_rate_zone_ranges import HeartRateZoneRanges
from swagger_client.models.lap import Lap
from swagger_client.models.lat_lng import LatLng
from swagger_client.models.meta_activity import MetaActivity
from swagger_client.models.meta_athlete import MetaAthlete
from swagger_client.models.meta_club import MetaClub
from swagger_client.models.photos_summary import PhotosSummary
from swagger_client.models.photos_summary_primary import PhotosSummaryPrimary
from swagger_client.models.polyline_map import PolylineMap
from swagger_client.models.power_zone_ranges import PowerZoneRanges
from swagger_client.models.route import Route
from swagger_client.models.route_direction import RouteDirection
from swagger_client.models.running_race import RunningRace
from swagger_client.models.segment_leaderboard import SegmentLeaderboard
from swagger_client.models.segment_leaderboard_entry import SegmentLeaderboardEntry
from swagger_client.models.split import Split
from swagger_client.models.stream_set import StreamSet
from swagger_client.models.summary_gear import SummaryGear
from swagger_client.models.summary_segment import SummarySegment
from swagger_client.models.summary_segment_effort import SummarySegmentEffort
from swagger_client.models.timed_zone_distribution import TimedZoneDistribution
from swagger_client.models.updatable_activity import UpdatableActivity
from swagger_client.models.upload import Upload
from swagger_client.models.zone_range import ZoneRange
from swagger_client.models.zone_ranges import ZoneRanges
from swagger_client.models.zones import Zones
from swagger_client.models.altitude_stream import AltitudeStream
from swagger_client.models.cadence_stream import CadenceStream
from swagger_client.models.detailed_gear import DetailedGear
from swagger_client.models.detailed_segment import DetailedSegment
from swagger_client.models.detailed_segment_effort import DetailedSegmentEffort
from swagger_client.models.distance_stream import DistanceStream
from swagger_client.models.heartrate_stream import HeartrateStream
from swagger_client.models.lat_lng_stream import LatLngStream
from swagger_client.models.moving_stream import MovingStream
from swagger_client.models.power_stream import PowerStream
from swagger_client.models.smooth_grade_stream import SmoothGradeStream
from swagger_client.models.smooth_velocity_stream import SmoothVelocityStream
from swagger_client.models.summary_activity import SummaryActivity
from swagger_client.models.summary_athlete import SummaryAthlete
from swagger_client.models.summary_club import SummaryClub
from swagger_client.models.temperature_stream import TemperatureStream
from swagger_client.models.time_stream import TimeStream
from swagger_client.models.timed_zone_range import TimedZoneRange
from swagger_client.models.detailed_activity import DetailedActivity
from swagger_client.models.detailed_athlete import DetailedAthlete
from swagger_client.models.detailed_club import DetailedClub



# coding: utf-8

"""
    Strava API v3

    Strava API  # noqa: E501

    OpenAPI spec version: 3.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class Upload(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'int',
        'external_id': 'str',
        'error': 'str',
        'status': 'str',
        'activity_id': 'int'
    }

    attribute_map = {
        'id': 'id',
        'external_id': 'external_id',
        'error': 'error',
        'status': 'status',
        'activity_id': 'activity_id'
    }

    def __init__(self, id=None, external_id=None, error=None, status=None, activity_id=None):  # noqa: E501
        """Upload - a model defined in Swagger"""  # noqa: E501

        self._id = None
        self._external_id = None
        self._error = None
        self._status = None
        self._activity_id = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if external_id is not None:
            self.external_id = external_id
        if error is not None:
            self.error = error
        if status is not None:
            self.status = status
        if activity_id is not None:
            self.activity_id = activity_id

    @property
    def id(self):
        """Gets the id of this Upload.  # noqa: E501

        The unique identifier of the upload  # noqa: E501

        :return: The id of this Upload.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this Upload.

        The unique identifier of the upload  # noqa: E501

        :param id: The id of this Upload.  # noqa: E501
        :type: int
        """

        self._id = id

    @property
    def external_id(self):
        """Gets the external_id of this Upload.  # noqa: E501

        The external identifier of the upload  # noqa: E501

        :return: The external_id of this Upload.  # noqa: E501
        :rtype: str
        """
        return self._external_id

    @external_id.setter
    def external_id(self, external_id):
        """Sets the external_id of this Upload.

        The external identifier of the upload  # noqa: E501

        :param external_id: The external_id of this Upload.  # noqa: E501
        :type: str
        """

        self._external_id = external_id

    @property
    def error(self):
        """Gets the error of this Upload.  # noqa: E501

        The error associated with this upload  # noqa: E501

        :return: The error of this Upload.  # noqa: E501
        :rtype: str
        """
        return self._error

    @error.setter
    def error(self, error):
        """Sets the error of this Upload.

        The error associated with this upload  # noqa: E501

        :param error: The error of this Upload.  # noqa: E501
        :type: str
        """

        self._error = error

    @property
    def status(self):
        """Gets the status of this Upload.  # noqa: E501

        The status of this upload  # noqa: E501

        :return: The status of this Upload.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this Upload.

        The status of this upload  # noqa: E501

        :param status: The status of this Upload.  # noqa: E501
        :type: str
        """

        self._status = status

    @property
    def activity_id(self):
        """Gets the activity_id of this Upload.  # noqa: E501

        The identifier of the activity this upload resulted into  # noqa: E501

        :return: The activity_id of this Upload.  # noqa: E501
        :rtype: int
        """
        return self._activity_id

    @activity_id.setter
    def activity_id(self, activity_id):
        """Sets the activity_id of this Upload.

        The identifier of the activity this upload resulted into  # noqa: E501

        :param activity_id: The activity_id of this Upload.  # noqa: E501
        :type: int
        """

        self._activity_id = activity_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Upload, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Upload):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Strava API v3

    Strava API  # noqa: E501

    OpenAPI spec version: 3.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from swagger_client.models.altitude_stream import AltitudeStream  # noqa: F401,E501
from swagger_client.models.cadence_stream import CadenceStream  # noqa: F401,E501
from swagger_client.models.distance_stream import DistanceStream  # noqa: F401,E501
from swagger_client.models.heartrate_stream import HeartrateStream  # noqa: F401,E501
from swagger_client.models.lat_lng_stream import LatLngStream  # noqa: F401,E501
from swagger_client.models.moving_stream import MovingStream  # noqa: F401,E501
from swagger_client.models.power_stream import PowerStream  # noqa: F401,E501
from swagger_client.models.smooth_grade_stream import SmoothGradeStream  # noqa: F401,E501
from swagger_client.models.smooth_velocity_stream import SmoothVelocityStream  # noqa: F401,E501
from swagger_client.models.temperature_stream import TemperatureStream  # noqa: F401,E501
from swagger_client.models.time_stream import TimeStream  # noqa: F401,E501


class StreamSet(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'time': 'TimeStream',
        'distance': 'DistanceStream',
        'latlng': 'LatLngStream',
        'altitude': 'AltitudeStream',
        'velocity_smooth': 'SmoothVelocityStream',
        'heartrate': 'HeartrateStream',
        'cadence': 'CadenceStream',
        'watts': 'PowerStream',
        'temp': 'TemperatureStream',
        'moving': 'MovingStream',
        'grade_smooth': 'SmoothGradeStream'
    }

    attribute_map = {
        'time': 'time',
        'distance': 'distance',
        'latlng': 'latlng',
        'altitude': 'altitude',
        'velocity_smooth': 'velocity_smooth',
        'heartrate': 'heartrate',
        'cadence': 'cadence',
        'watts': 'watts',
        'temp': 'temp',
        'moving': 'moving',
        'grade_smooth': 'grade_smooth'
    }

    def __init__(self, time=None, distance=None, latlng=None, altitude=None, velocity_smooth=None, heartrate=None, cadence=None, watts=None, temp=None, moving=None, grade_smooth=None):  # noqa: E501
        """StreamSet - a model defined in Swagger"""  # noqa: E501

        self._time = None
        self._distance = None
        self._latlng = None
        self._altitude = None
        self._velocity_smooth = None
        self._heartrate = None
        self._cadence = None
        self._watts = None
        self._temp = None
        self._moving = None
        self._grade_smooth = None
        self.discriminator = None

        if time is not None:
            self.time = time
        if distance is not None:
            self.distance = distance
        if latlng is not None:
            self.latlng = latlng
        if altitude is not None:
            self.altitude = altitude
        if velocity_smooth is not None:
            self.velocity_smooth = velocity_smooth
        if heartrate is not None:
            self.heartrate = heartrate
        if cadence is not None:
            self.cadence = cadence
        if watts is not None:
            self.watts = watts
        if temp is not None:
            self.temp = temp
        if moving is not None:
            self.moving = moving
        if grade_smooth is not None:
            self.grade_smooth = grade_smooth

    @property
    def time(self):
        """Gets the time of this StreamSet.  # noqa: E501


        :return: The time of this StreamSet.  # noqa: E501
        :rtype: TimeStream
        """
        return self._time

    @time.setter
    def time(self, time):
        """Sets the time of this StreamSet.


        :param time: The time of this StreamSet.  # noqa: E501
        :type: TimeStream
        """

        self._time = time

    @property
    def distance(self):
        """Gets the distance of this StreamSet.  # noqa: E501


        :return: The distance of this StreamSet.  # noqa: E501
        :rtype: DistanceStream
        """
        return self._distance

    @distance.setter
    def distance(self, distance):
        """Sets the distance of this StreamSet.


        :param distance: The distance of this StreamSet.  # noqa: E501
        :type: DistanceStream
        """

        self._distance = distance

    @property
    def latlng(self):
        """Gets the latlng of this StreamSet.  # noqa: E501


        :return: The latlng of this StreamSet.  # noqa: E501
        :rtype: LatLngStream
        """
        return self._latlng

    @latlng.setter
    def latlng(self, latlng):
        """Sets the latlng of this StreamSet.


        :param latlng: The latlng of this StreamSet.  # noqa: E501
        :type: LatLngStream
        """

        self._latlng = latlng

    @property
    def altitude(self):
        """Gets the altitude of this StreamSet.  # noqa: E501


        :return: The altitude of this StreamSet.  # noqa: E501
        :rtype: AltitudeStream
        """
        return self._altitude

    @altitude.setter
    def altitude(self, altitude):
        """Sets the altitude of this StreamSet.


        :param altitude: The altitude of this StreamSet.  # noqa: E501
        :type: AltitudeStream
        """

        self._altitude = altitude

    @property
    def velocity_smooth(self):
        """Gets the velocity_smooth of this StreamSet.  # noqa: E501


        :return: The velocity_smooth of this StreamSet.  # noqa: E501
        :rtype: SmoothVelocityStream
        """
        return self._velocity_smooth

    @velocity_smooth.setter
    def velocity_smooth(self, velocity_smooth):
        """Sets the velocity_smooth of this StreamSet.


        :param velocity_smooth: The velocity_smooth of this StreamSet.  # noqa: E501
        :type: SmoothVelocityStream
        """

        self._velocity_smooth = velocity_smooth

    @property
    def heartrate(self):
        """Gets the heartrate of this StreamSet.  # noqa: E501


        :return: The heartrate of this StreamSet.  # noqa: E501
        :rtype: HeartrateStream
        """
        return self._heartrate

    @heartrate.setter
    def heartrate(self, heartrate):
        """Sets the heartrate of this StreamSet.


        :param heartrate: The heartrate of this StreamSet.  # noqa: E501
        :type: HeartrateStream
        """

        self._heartrate = heartrate

    @property
    def cadence(self):
        """Gets the cadence of this StreamSet.  # noqa: E501


        :return: The cadence of this StreamSet.  # noqa: E501
        :rtype: CadenceStream
        """
        return self._cadence

    @cadence.setter
    def cadence(self, cadence):
        """Sets the cadence of this StreamSet.


        :param cadence: The cadence of this StreamSet.  # noqa: E501
        :type: CadenceStream
        """

        self._cadence = cadence

    @property
    def watts(self):
        """Gets the watts of this StreamSet.  # noqa: E501


        :return: The watts of this StreamSet.  # noqa: E501
        :rtype: PowerStream
        """
        return self._watts

    @watts.setter
    def watts(self, watts):
        """Sets the watts of this StreamSet.


        :param watts: The watts of this StreamSet.  # noqa: E501
        :type: PowerStream
        """

        self._watts = watts

    @property
    def temp(self):
        """Gets the temp of this StreamSet.  # noqa: E501


        :return: The temp of this StreamSet.  # noqa: E501
        :rtype: TemperatureStream
        """
        return self._temp

    @temp.setter
    def temp(self, temp):
        """Sets the temp of this StreamSet.


        :param temp: The temp of this StreamSet.  # noqa: E501
        :type: TemperatureStream
        """

        self._temp = temp

    @property
    def moving(self):
        """Gets the moving of this StreamSet.  # noqa: E501


        :return: The moving of this StreamSet.  # noqa: E501
        :rtype: MovingStream
        """
        return self._moving

    @moving.setter
    def moving(self, moving):
        """Sets the moving of this StreamSet.


        :param moving: The moving of this StreamSet.  # noqa: E501
        :type: MovingStream
        """

        self._moving = moving

    @property
    def grade_smooth(self):
        """Gets the grade_smooth of this StreamSet.  # noqa: E501


        :return: The grade_smooth of this StreamSet.  # noqa: E501
        :rtype: SmoothGradeStream
        """
        return self._grade_smooth

    @grade_smooth.setter
    def grade_smooth(self, grade_smooth):
        """Sets the grade_smooth of this StreamSet.


        :param grade_smooth: The grade_smooth of this StreamSet.  # noqa: E501
        :type: SmoothGradeStream
        """

        self._grade_smooth = grade_smooth

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(StreamSet, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, StreamSet):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Strava API v3

    Strava API  # noqa: E501

    OpenAPI spec version: 3.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from swagger_client.models.meta_activity import MetaActivity  # noqa: F401,E501
from swagger_client.models.meta_athlete import MetaAthlete  # noqa: F401,E501
from swagger_client.models.summary_segment import SummarySegment  # noqa: F401,E501
from swagger_client.models.summary_segment_effort import SummarySegmentEffort  # noqa: F401,E501


class DetailedSegmentEffort(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'int',
        'elapsed_time': 'int',
        'start_date': 'datetime',
        'start_date_local': 'datetime',
        'distance': 'float',
        'is_kom': 'bool',
        'name': 'str',
        'activity': 'MetaActivity',
        'athlete': 'MetaAthlete',
        'moving_time': 'int',
        'start_index': 'int',
        'end_index': 'int',
        'average_cadence': 'float',
        'average_watts': 'float',
        'device_watts': 'bool',
        'average_heartrate': 'float',
        'max_heartrate': 'float',
        'segment': 'SummarySegment',
        'kom_rank': 'int',
        'pr_rank': 'int',
        'hidden': 'bool'
    }

    attribute_map = {
        'id': 'id',
        'elapsed_time': 'elapsed_time',
        'start_date': 'start_date',
        'start_date_local': 'start_date_local',
        'distance': 'distance',
        'is_kom': 'is_kom',
        'name': 'name',
        'activity': 'activity',
        'athlete': 'athlete',
        'moving_time': 'moving_time',
        'start_index': 'start_index',
        'end_index': 'end_index',
        'average_cadence': 'average_cadence',
        'average_watts': 'average_watts',
        'device_watts': 'device_watts',
        'average_heartrate': 'average_heartrate',
        'max_heartrate': 'max_heartrate',
        'segment': 'segment',
        'kom_rank': 'kom_rank',
        'pr_rank': 'pr_rank',
        'hidden': 'hidden'
    }

    def __init__(self, id=None, elapsed_time=None, start_date=None, start_date_local=None, distance=None, is_kom=None, name=None, activity=None, athlete=None, moving_time=None, start_index=None, end_index=None, average_cadence=None, average_watts=None, device_watts=None, average_heartrate=None, max_heartrate=None, segment=None, kom_rank=None, pr_rank=None, hidden=None):  # noqa: E501
        """DetailedSegmentEffort - a model defined in Swagger"""  # noqa: E501

        self._id = None
        self._elapsed_time = None
        self._start_date = None
        self._start_date_local = None
        self._distance = None
        self._is_kom = None
        self._name = None
        self._activity = None
        self._athlete = None
        self._moving_time = None
        self._start_index = None
        self._end_index = None
        self._average_cadence = None
        self._average_watts = None
        self._device_watts = None
        self._average_heartrate = None
        self._max_heartrate = None
        self._segment = None
        self._kom_rank = None
        self._pr_rank = None
        self._hidden = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if elapsed_time is not None:
            self.elapsed_time = elapsed_time
        if start_date is not None:
            self.start_date = start_date
        if start_date_local is not None:
            self.start_date_local = start_date_local
        if distance is not None:
            self.distance = distance
        if is_kom is not None:
            self.is_kom = is_kom
        if name is not None:
            self.name = name
        if activity is not None:
            self.activity = activity
        if athlete is not None:
            self.athlete = athlete
        if moving_time is not None:
            self.moving_time = moving_time
        if start_index is not None:
            self.start_index = start_index
        if end_index is not None:
            self.end_index = end_index
        if average_cadence is not None:
            self.average_cadence = average_cadence
        if average_watts is not None:
            self.average_watts = average_watts
        if device_watts is not None:
            self.device_watts = device_watts
        if average_heartrate is not None:
            self.average_heartrate = average_heartrate
        if max_heartrate is not None:
            self.max_heartrate = max_heartrate
        if segment is not None:
            self.segment = segment
        if kom_rank is not None:
            self.kom_rank = kom_rank
        if pr_rank is not None:
            self.pr_rank = pr_rank
        if hidden is not None:
            self.hidden = hidden

    @property
    def id(self):
        """Gets the id of this DetailedSegmentEffort.  # noqa: E501

        The unique identifier of this effort  # noqa: E501

        :return: The id of this DetailedSegmentEffort.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this DetailedSegmentEffort.

        The unique identifier of this effort  # noqa: E501

        :param id: The id of this DetailedSegmentEffort.  # noqa: E501
        :type: int
        """

        self._id = id

    @property
    def elapsed_time(self):
        """Gets the elapsed_time of this DetailedSegmentEffort.  # noqa: E501

        The effort's elapsed time  # noqa: E501

        :return: The elapsed_time of this DetailedSegmentEffort.  # noqa: E501
        :rtype: int
        """
        return self._elapsed_time

    @elapsed_time.setter
    def elapsed_time(self, elapsed_time):
        """Sets the elapsed_time of this DetailedSegmentEffort.

        The effort's elapsed time  # noqa: E501

        :param elapsed_time: The elapsed_time of this DetailedSegmentEffort.  # noqa: E501
        :type: int
        """

        self._elapsed_time = elapsed_time

    @property
    def start_date(self):
        """Gets the start_date of this DetailedSegmentEffort.  # noqa: E501

        The time at which the effort was started.  # noqa: E501

        :return: The start_date of this DetailedSegmentEffort.  # noqa: E501
        :rtype: datetime
        """
        return self._start_date

    @start_date.setter
    def start_date(self, start_date):
        """Sets the start_date of this DetailedSegmentEffort.

        The time at which the effort was started.  # noqa: E501

        :param start_date: The start_date of this DetailedSegmentEffort.  # noqa: E501
        :type: datetime
        """

        self._start_date = start_date

    @property
    def start_date_local(self):
        """Gets the start_date_local of this DetailedSegmentEffort.  # noqa: E501

        The time at which the effort was started in the local timezone.  # noqa: E501

        :return: The start_date_local of this DetailedSegmentEffort.  # noqa: E501
        :rtype: datetime
        """
        return self._start_date_local

    @start_date_local.setter
    def start_date_local(self, start_date_local):
        """Sets the start_date_local of this DetailedSegmentEffort.

        The time at which the effort was started in the local timezone.  # noqa: E501

        :param start_date_local: The start_date_local of this DetailedSegmentEffort.  # noqa: E501
        :type: datetime
        """

        self._start_date_local = start_date_local

    @property
    def distance(self):
        """Gets the distance of this DetailedSegmentEffort.  # noqa: E501

        The effort's distance in meters  # noqa: E501

        :return: The distance of this DetailedSegmentEffort.  # noqa: E501
        :rtype: float
        """
        return self._distance

    @distance.setter
    def distance(self, distance):
        """Sets the distance of this DetailedSegmentEffort.

        The effort's distance in meters  # noqa: E501

        :param distance: The distance of this DetailedSegmentEffort.  # noqa: E501
        :type: float
        """

        self._distance = distance

    @property
    def is_kom(self):
        """Gets the is_kom of this DetailedSegmentEffort.  # noqa: E501

        Whether this effort is the current best on the leaderboard  # noqa: E501

        :return: The is_kom of this DetailedSegmentEffort.  # noqa: E501
        :rtype: bool
        """
        return self._is_kom

    @is_kom.setter
    def is_kom(self, is_kom):
        """Sets the is_kom of this DetailedSegmentEffort.

        Whether this effort is the current best on the leaderboard  # noqa: E501

        :param is_kom: The is_kom of this DetailedSegmentEffort.  # noqa: E501
        :type: bool
        """

        self._is_kom = is_kom

    @property
    def name(self):
        """Gets the name of this DetailedSegmentEffort.  # noqa: E501

        The name of the segment on which this effort was performed  # noqa: E501

        :return: The name of this DetailedSegmentEffort.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this DetailedSegmentEffort.

        The name of the segment on which this effort was performed  # noqa: E501

        :param name: The name of this DetailedSegmentEffort.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def activity(self):
        """Gets the activity of this DetailedSegmentEffort.  # noqa: E501


        :return: The activity of this DetailedSegmentEffort.  # noqa: E501
        :rtype: MetaActivity
        """
        return self._activity

    @activity.setter
    def activity(self, activity):
        """Sets the activity of this DetailedSegmentEffort.


        :param activity: The activity of this DetailedSegmentEffort.  # noqa: E501
        :type: MetaActivity
        """

        self._activity = activity

    @property
    def athlete(self):
        """Gets the athlete of this DetailedSegmentEffort.  # noqa: E501


        :return: The athlete of this DetailedSegmentEffort.  # noqa: E501
        :rtype: MetaAthlete
        """
        return self._athlete

    @athlete.setter
    def athlete(self, athlete):
        """Sets the athlete of this DetailedSegmentEffort.


        :param athlete: The athlete of this DetailedSegmentEffort.  # noqa: E501
        :type: MetaAthlete
        """

        self._athlete = athlete

    @property
    def moving_time(self):
        """Gets the moving_time of this DetailedSegmentEffort.  # noqa: E501

        The effort's moving time  # noqa: E501

        :return: The moving_time of this DetailedSegmentEffort.  # noqa: E501
        :rtype: int
        """
        return self._moving_time

    @moving_time.setter
    def moving_time(self, moving_time):
        """Sets the moving_time of this DetailedSegmentEffort.

        The effort's moving time  # noqa: E501

        :param moving_time: The moving_time of this DetailedSegmentEffort.  # noqa: E501
        :type: int
        """

        self._moving_time = moving_time

    @property
    def start_index(self):
        """Gets the start_index of this DetailedSegmentEffort.  # noqa: E501

        The start index of this effort in its activity's stream  # noqa: E501

        :return: The start_index of this DetailedSegmentEffort.  # noqa: E501
        :rtype: int
        """
        return self._start_index

    @start_index.setter
    def start_index(self, start_index):
        """Sets the start_index of this DetailedSegmentEffort.

        The start index of this effort in its activity's stream  # noqa: E501

        :param start_index: The start_index of this DetailedSegmentEffort.  # noqa: E501
        :type: int
        """

        self._start_index = start_index

    @property
    def end_index(self):
        """Gets the end_index of this DetailedSegmentEffort.  # noqa: E501

        The end index of this effort in its activity's stream  # noqa: E501

        :return: The end_index of this DetailedSegmentEffort.  # noqa: E501
        :rtype: int
        """
        return self._end_index

    @end_index.setter
    def end_index(self, end_index):
        """Sets the end_index of this DetailedSegmentEffort.

        The end index of this effort in its activity's stream  # noqa: E501

        :param end_index: The end_index of this DetailedSegmentEffort.  # noqa: E501
        :type: int
        """

        self._end_index = end_index

    @property
    def average_cadence(self):
        """Gets the average_cadence of this DetailedSegmentEffort.  # noqa: E501

        The effort's average cadence  # noqa: E501

        :return: The average_cadence of this DetailedSegmentEffort.  # noqa: E501
        :rtype: float
        """
        return self._average_cadence

    @average_cadence.setter
    def average_cadence(self, average_cadence):
        """Sets the average_cadence of this DetailedSegmentEffort.

        The effort's average cadence  # noqa: E501

        :param average_cadence: The average_cadence of this DetailedSegmentEffort.  # noqa: E501
        :type: float
        """

        self._average_cadence = average_cadence

    @property
    def average_watts(self):
        """Gets the average_watts of this DetailedSegmentEffort.  # noqa: E501

        The average wattage of this effort  # noqa: E501

        :return: The average_watts of this DetailedSegmentEffort.  # noqa: E501
        :rtype: float
        """
        return self._average_watts

    @average_watts.setter
    def average_watts(self, average_watts):
        """Sets the average_watts of this DetailedSegmentEffort.

        The average wattage of this effort  # noqa: E501

        :param average_watts: The average_watts of this DetailedSegmentEffort.  # noqa: E501
        :type: float
        """

        self._average_watts = average_watts

    @property
    def device_watts(self):
        """Gets the device_watts of this DetailedSegmentEffort.  # noqa: E501

        For riding efforts, whether the wattage was reported by a dedicated recording device  # noqa: E501

        :return: The device_watts of this DetailedSegmentEffort.  # noqa: E501
        :rtype: bool
        """
        return self._device_watts

    @device_watts.setter
    def device_watts(self, device_watts):
        """Sets the device_watts of this DetailedSegmentEffort.

        For riding efforts, whether the wattage was reported by a dedicated recording device  # noqa: E501

        :param device_watts: The device_watts of this DetailedSegmentEffort.  # noqa: E501
        :type: bool
        """

        self._device_watts = device_watts

    @property
    def average_heartrate(self):
        """Gets the average_heartrate of this DetailedSegmentEffort.  # noqa: E501

        The heart heart rate of the athlete during this effort  # noqa: E501

        :return: The average_heartrate of this DetailedSegmentEffort.  # noqa: E501
        :rtype: float
        """
        return self._average_heartrate

    @average_heartrate.setter
    def average_heartrate(self, average_heartrate):
        """Sets the average_heartrate of this DetailedSegmentEffort.

        The heart heart rate of the athlete during this effort  # noqa: E501

        :param average_heartrate: The average_heartrate of this DetailedSegmentEffort.  # noqa: E501
        :type: float
        """

        self._average_heartrate = average_heartrate

    @property
    def max_heartrate(self):
        """Gets the max_heartrate of this DetailedSegmentEffort.  # noqa: E501

        The maximum heart rate of the athlete during this effort  # noqa: E501

        :return: The max_heartrate of this DetailedSegmentEffort.  # noqa: E501
        :rtype: float
        """
        return self._max_heartrate

    @max_heartrate.setter
    def max_heartrate(self, max_heartrate):
        """Sets the max_heartrate of this DetailedSegmentEffort.

        The maximum heart rate of the athlete during this effort  # noqa: E501

        :param max_heartrate: The max_heartrate of this DetailedSegmentEffort.  # noqa: E501
        :type: float
        """

        self._max_heartrate = max_heartrate

    @property
    def segment(self):
        """Gets the segment of this DetailedSegmentEffort.  # noqa: E501


        :return: The segment of this DetailedSegmentEffort.  # noqa: E501
        :rtype: SummarySegment
        """
        return self._segment

    @segment.setter
    def segment(self, segment):
        """Sets the segment of this DetailedSegmentEffort.


        :param segment: The segment of this DetailedSegmentEffort.  # noqa: E501
        :type: SummarySegment
        """

        self._segment = segment

    @property
    def kom_rank(self):
        """Gets the kom_rank of this DetailedSegmentEffort.  # noqa: E501

        The rank of the effort on the global leaderboard if it belongs in the top 10 at the time of upload  # noqa: E501

        :return: The kom_rank of this DetailedSegmentEffort.  # noqa: E501
        :rtype: int
        """
        return self._kom_rank

    @kom_rank.setter
    def kom_rank(self, kom_rank):
        """Sets the kom_rank of this DetailedSegmentEffort.

        The rank of the effort on the global leaderboard if it belongs in the top 10 at the time of upload  # noqa: E501

        :param kom_rank: The kom_rank of this DetailedSegmentEffort.  # noqa: E501
        :type: int
        """
        if kom_rank is not None and kom_rank > 10:  # noqa: E501
            raise ValueError("Invalid value for `kom_rank`, must be a value less than or equal to `10`")  # noqa: E501
        if kom_rank is not None and kom_rank < 1:  # noqa: E501
            raise ValueError("Invalid value for `kom_rank`, must be a value greater than or equal to `1`")  # noqa: E501

        self._kom_rank = kom_rank

    @property
    def pr_rank(self):
        """Gets the pr_rank of this DetailedSegmentEffort.  # noqa: E501

        The rank of the effort on the athlete's leaderboard if it belongs in the top 3 at the time of upload  # noqa: E501

        :return: The pr_rank of this DetailedSegmentEffort.  # noqa: E501
        :rtype: int
        """
        return self._pr_rank

    @pr_rank.setter
    def pr_rank(self, pr_rank):
        """Sets the pr_rank of this DetailedSegmentEffort.

        The rank of the effort on the athlete's leaderboard if it belongs in the top 3 at the time of upload  # noqa: E501

        :param pr_rank: The pr_rank of this DetailedSegmentEffort.  # noqa: E501
        :type: int
        """
        if pr_rank is not None and pr_rank > 3:  # noqa: E501
            raise ValueError("Invalid value for `pr_rank`, must be a value less than or equal to `3`")  # noqa: E501
        if pr_rank is not None and pr_rank < 1:  # noqa: E501
            raise ValueError("Invalid value for `pr_rank`, must be a value greater than or equal to `1`")  # noqa: E501

        self._pr_rank = pr_rank

    @property
    def hidden(self):
        """Gets the hidden of this DetailedSegmentEffort.  # noqa: E501

        Whether this effort should be hidden when viewed within an activity  # noqa: E501

        :return: The hidden of this DetailedSegmentEffort.  # noqa: E501
        :rtype: bool
        """
        return self._hidden

    @hidden.setter
    def hidden(self, hidden):
        """Sets the hidden of this DetailedSegmentEffort.

        Whether this effort should be hidden when viewed within an activity  # noqa: E501

        :param hidden: The hidden of this DetailedSegmentEffort.  # noqa: E501
        :type: bool
        """

        self._hidden = hidden

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(DetailedSegmentEffort, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DetailedSegmentEffort):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



from __future__ import absolute_import

# flake8: noqa

# import apis into api package
from swagger_client.api.activities_api import ActivitiesApi
from swagger_client.api.athletes_api import AthletesApi
from swagger_client.api.clubs_api import ClubsApi
from swagger_client.api.gears_api import GearsApi
from swagger_client.api.routes_api import RoutesApi
from swagger_client.api.running_races_api import RunningRacesApi
from swagger_client.api.segment_efforts_api import SegmentEffortsApi
from swagger_client.api.segments_api import SegmentsApi
from swagger_client.api.streams_api import StreamsApi
from swagger_client.api.uploads_api import UploadsApi



# coding: utf-8

"""
    Strava API v3

    Strava API  # noqa: E501

    OpenAPI spec version: 3.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from swagger_client.api_client import ApiClient


class ActivitiesApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def create_activity(self, name, type, start_date_local, elapsed_time, **kwargs):  # noqa: E501
        """Create an Activity  # noqa: E501

        Creates a manual activity for an athlete, requires activity:write scope.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_activity(name, type, start_date_local, elapsed_time, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str name: The name of the activity. (required)
        :param str type: Type of activity. For example - Run, Ride etc. (required)
        :param ERRORUNKNOWN start_date_local: ISO 8601 formatted date time. (required)
        :param int elapsed_time: In seconds. (required)
        :param str description: Description of the activity.
        :param float distance: In meters.
        :param int trainer: Set to 1 to mark as a trainer activity.
        :param ERRORUNKNOWN photo_ids: List of native photo ids to attach to the activity.
        :param int commute: Set to 1 to mark as commute.
        :return: DetailedActivity
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.create_activity_with_http_info(name, type, start_date_local, elapsed_time, **kwargs)  # noqa: E501
        else:
            (data) = self.create_activity_with_http_info(name, type, start_date_local, elapsed_time, **kwargs)  # noqa: E501
            return data

    def create_activity_with_http_info(self, name, type, start_date_local, elapsed_time, **kwargs):  # noqa: E501
        """Create an Activity  # noqa: E501

        Creates a manual activity for an athlete, requires activity:write scope.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_activity_with_http_info(name, type, start_date_local, elapsed_time, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str name: The name of the activity. (required)
        :param str type: Type of activity. For example - Run, Ride etc. (required)
        :param ERRORUNKNOWN start_date_local: ISO 8601 formatted date time. (required)
        :param int elapsed_time: In seconds. (required)
        :param str description: Description of the activity.
        :param float distance: In meters.
        :param int trainer: Set to 1 to mark as a trainer activity.
        :param ERRORUNKNOWN photo_ids: List of native photo ids to attach to the activity.
        :param int commute: Set to 1 to mark as commute.
        :return: DetailedActivity
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['name', 'type', 'start_date_local', 'elapsed_time', 'description', 'distance', 'trainer', 'photo_ids', 'commute']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_activity" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'name' is set
        if ('name' not in params or
                params['name'] is None):
            raise ValueError("Missing the required parameter `name` when calling `create_activity`")  # noqa: E501
        # verify the required parameter 'type' is set
        if ('type' not in params or
                params['type'] is None):
            raise ValueError("Missing the required parameter `type` when calling `create_activity`")  # noqa: E501
        # verify the required parameter 'start_date_local' is set
        if ('start_date_local' not in params or
                params['start_date_local'] is None):
            raise ValueError("Missing the required parameter `start_date_local` when calling `create_activity`")  # noqa: E501
        # verify the required parameter 'elapsed_time' is set
        if ('elapsed_time' not in params or
                params['elapsed_time'] is None):
            raise ValueError("Missing the required parameter `elapsed_time` when calling `create_activity`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}
        if 'name' in params:
            form_params.append(('name', params['name']))  # noqa: E501
        if 'type' in params:
            form_params.append(('type', params['type']))  # noqa: E501
        if 'start_date_local' in params:
            form_params.append(('start_date_local', params['start_date_local']))  # noqa: E501
        if 'elapsed_time' in params:
            form_params.append(('elapsed_time', params['elapsed_time']))  # noqa: E501
        if 'description' in params:
            form_params.append(('description', params['description']))  # noqa: E501
        if 'distance' in params:
            form_params.append(('distance', params['distance']))  # noqa: E501
        if 'trainer' in params:
            form_params.append(('trainer', params['trainer']))  # noqa: E501
        if 'photo_ids' in params:
            form_params.append(('photo_ids', params['photo_ids']))  # noqa: E501
        if 'commute' in params:
            form_params.append(('commute', params['commute']))  # noqa: E501

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['strava_oauth']  # noqa: E501

        return self.api_client.call_api(
            '/activities', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='DetailedActivity',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_activity_by_id(self, id, **kwargs):  # noqa: E501
        """Get Activity  # noqa: E501

        Returns the given activity that is owned by the authenticated athlete. Requires activity:read for Everyone and Followers activities. Requires activity:read_all for Only Me activities.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_activity_by_id(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int id: The identifier of the activity. (required)
        :param bool include_all_efforts: To include all segments efforts.
        :return: DetailedActivity
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_activity_by_id_with_http_info(id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_activity_by_id_with_http_info(id, **kwargs)  # noqa: E501
            return data

    def get_activity_by_id_with_http_info(self, id, **kwargs):  # noqa: E501
        """Get Activity  # noqa: E501

        Returns the given activity that is owned by the authenticated athlete. Requires activity:read for Everyone and Followers activities. Requires activity:read_all for Only Me activities.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_activity_by_id_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int id: The identifier of the activity. (required)
        :param bool include_all_efforts: To include all segments efforts.
        :return: DetailedActivity
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id', 'include_all_efforts']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_activity_by_id" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `get_activity_by_id`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []
        if 'include_all_efforts' in params:
            query_params.append(('include_all_efforts', params['include_all_efforts']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['strava_oauth']  # noqa: E501

        return self.api_client.call_api(
            '/activities/{id}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='DetailedActivity',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_comments_by_activity_id(self, id, **kwargs):  # noqa: E501
        """List Activity Comments  # noqa: E501

        Returns the comments on the given activity. Requires activity:read for Everyone and Followers activities. Requires activity:read_all for Only Me activities.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_comments_by_activity_id(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int id: The identifier of the activity. (required)
        :param int page: Page number.
        :param int per_page: Number of items per page. Defaults to 30.
        :return: list[Comment]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_comments_by_activity_id_with_http_info(id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_comments_by_activity_id_with_http_info(id, **kwargs)  # noqa: E501
            return data

    def get_comments_by_activity_id_with_http_info(self, id, **kwargs):  # noqa: E501
        """List Activity Comments  # noqa: E501

        Returns the comments on the given activity. Requires activity:read for Everyone and Followers activities. Requires activity:read_all for Only Me activities.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_comments_by_activity_id_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int id: The identifier of the activity. (required)
        :param int page: Page number.
        :param int per_page: Number of items per page. Defaults to 30.
        :return: list[Comment]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id', 'page', 'per_page']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_comments_by_activity_id" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `get_comments_by_activity_id`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []
        if 'page' in params:
            query_params.append(('page', params['page']))  # noqa: E501
        if 'per_page' in params:
            query_params.append(('per_page', params['per_page']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['strava_oauth']  # noqa: E501

        return self.api_client.call_api(
            '/activities/{id}/comments', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[Comment]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_kudoers_by_activity_id(self, id, **kwargs):  # noqa: E501
        """List Activity Kudoers  # noqa: E501

        Returns the athletes who kudoed an activity identified by an identifier. Requires activity:read for Everyone and Followers activities. Requires activity:read_all for Only Me activities.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_kudoers_by_activity_id(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int id: The identifier of the activity. (required)
        :param int page: Page number.
        :param int per_page: Number of items per page. Defaults to 30.
        :return: list[SummaryAthlete]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_kudoers_by_activity_id_with_http_info(id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_kudoers_by_activity_id_with_http_info(id, **kwargs)  # noqa: E501
            return data

    def get_kudoers_by_activity_id_with_http_info(self, id, **kwargs):  # noqa: E501
        """List Activity Kudoers  # noqa: E501

        Returns the athletes who kudoed an activity identified by an identifier. Requires activity:read for Everyone and Followers activities. Requires activity:read_all for Only Me activities.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_kudoers_by_activity_id_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int id: The identifier of the activity. (required)
        :param int page: Page number.
        :param int per_page: Number of items per page. Defaults to 30.
        :return: list[SummaryAthlete]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id', 'page', 'per_page']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_kudoers_by_activity_id" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `get_kudoers_by_activity_id`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []
        if 'page' in params:
            query_params.append(('page', params['page']))  # noqa: E501
        if 'per_page' in params:
            query_params.append(('per_page', params['per_page']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['strava_oauth']  # noqa: E501

        return self.api_client.call_api(
            '/activities/{id}/kudos', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[SummaryAthlete]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_laps_by_activity_id(self, id, **kwargs):  # noqa: E501
        """List Activity Laps  # noqa: E501

        Returns the laps of an activity identified by an identifier. Requires activity:read for Everyone and Followers activities. Requires activity:read_all for Only Me activities.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_laps_by_activity_id(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int id: The identifier of the activity. (required)
        :return: list[Lap]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_laps_by_activity_id_with_http_info(id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_laps_by_activity_id_with_http_info(id, **kwargs)  # noqa: E501
            return data

    def get_laps_by_activity_id_with_http_info(self, id, **kwargs):  # noqa: E501
        """List Activity Laps  # noqa: E501

        Returns the laps of an activity identified by an identifier. Requires activity:read for Everyone and Followers activities. Requires activity:read_all for Only Me activities.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_laps_by_activity_id_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int id: The identifier of the activity. (required)
        :return: list[Lap]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_laps_by_activity_id" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `get_laps_by_activity_id`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['strava_oauth']  # noqa: E501

        return self.api_client.call_api(
            '/activities/{id}/laps', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[Lap]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_logged_in_athlete_activities(self, **kwargs):  # noqa: E501
        """List Athlete Activities  # noqa: E501

        Returns the activities of an athlete for a specific identifier. Requires activity:read. Only Me activities will be filtered out unless requested by a token with activity:read_all.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_logged_in_athlete_activities(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int before: An epoch timestamp to use for filtering activities that have taken place before a certain time.
        :param int after: An epoch timestamp to use for filtering activities that have taken place after a certain time.
        :param int page: Page number.
        :param int per_page: Number of items per page. Defaults to 30.
        :return: list[SummaryActivity]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_logged_in_athlete_activities_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_logged_in_athlete_activities_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_logged_in_athlete_activities_with_http_info(self, **kwargs):  # noqa: E501
        """List Athlete Activities  # noqa: E501

        Returns the activities of an athlete for a specific identifier. Requires activity:read. Only Me activities will be filtered out unless requested by a token with activity:read_all.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_logged_in_athlete_activities_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int before: An epoch timestamp to use for filtering activities that have taken place before a certain time.
        :param int after: An epoch timestamp to use for filtering activities that have taken place after a certain time.
        :param int page: Page number.
        :param int per_page: Number of items per page. Defaults to 30.
        :return: list[SummaryActivity]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['before', 'after', 'page', 'per_page']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_logged_in_athlete_activities" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'before' in params:
            query_params.append(('before', params['before']))  # noqa: E501
        if 'after' in params:
            query_params.append(('after', params['after']))  # noqa: E501
        if 'page' in params:
            query_params.append(('page', params['page']))  # noqa: E501
        if 'per_page' in params:
            query_params.append(('per_page', params['per_page']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['strava_oauth']  # noqa: E501

        return self.api_client.call_api(
            '/athlete/activities', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[SummaryActivity]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_zones_by_activity_id(self, id, **kwargs):  # noqa: E501
        """Get Activity Zones  # noqa: E501

        Summit Feature. Returns the zones of a given activity. Requires activity:read for Everyone and Followers activities. Requires activity:read_all for Only Me activities.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_zones_by_activity_id(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int id: The identifier of the activity. (required)
        :return: list[ActivityZone]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_zones_by_activity_id_with_http_info(id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_zones_by_activity_id_with_http_info(id, **kwargs)  # noqa: E501
            return data

    def get_zones_by_activity_id_with_http_info(self, id, **kwargs):  # noqa: E501
        """Get Activity Zones  # noqa: E501

        Summit Feature. Returns the zones of a given activity. Requires activity:read for Everyone and Followers activities. Requires activity:read_all for Only Me activities.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_zones_by_activity_id_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int id: The identifier of the activity. (required)
        :return: list[ActivityZone]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_zones_by_activity_id" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `get_zones_by_activity_id`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['strava_oauth']  # noqa: E501

        return self.api_client.call_api(
            '/activities/{id}/zones', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[ActivityZone]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def update_activity_by_id(self, id, **kwargs):  # noqa: E501
        """Update Activity  # noqa: E501

        Updates the given activity that is owned by the authenticated athlete. Requires activity:write. Also requires activity:read_all in order to update Only Me activities  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_activity_by_id(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int id: The identifier of the activity. (required)
        :param UpdatableActivity body:
        :return: DetailedActivity
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.update_activity_by_id_with_http_info(id, **kwargs)  # noqa: E501
        else:
            (data) = self.update_activity_by_id_with_http_info(id, **kwargs)  # noqa: E501
            return data

    def update_activity_by_id_with_http_info(self, id, **kwargs):  # noqa: E501
        """Update Activity  # noqa: E501

        Updates the given activity that is owned by the authenticated athlete. Requires activity:write. Also requires activity:read_all in order to update Only Me activities  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_activity_by_id_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int id: The identifier of the activity. (required)
        :param UpdatableActivity body:
        :return: DetailedActivity
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id', 'body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_activity_by_id" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `update_activity_by_id`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['strava_oauth']  # noqa: E501

        return self.api_client.call_api(
            '/activities/{id}', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='DetailedActivity',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Strava API v3

    Strava API  # noqa: E501

    OpenAPI spec version: 3.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from swagger_client.models.lat_lng import LatLng  # noqa: F401,E501


class ExplorerSegment(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'int',
        'name': 'str',
        'climb_category': 'int',
        'climb_category_desc': 'str',
        'avg_grade': 'float',
        'start_latlng': 'LatLng',
        'end_latlng': 'LatLng',
        'elev_difference': 'float',
        'distance': 'float',
        'points': 'str'
    }

    attribute_map = {
        'id': 'id',
        'name': 'name',
        'climb_category': 'climb_category',
        'climb_category_desc': 'climb_category_desc',
        'avg_grade': 'avg_grade',
        'start_latlng': 'start_latlng',
        'end_latlng': 'end_latlng',
        'elev_difference': 'elev_difference',
        'distance': 'distance',
        'points': 'points'
    }

    def __init__(self, id=None, name=None, climb_category=None, climb_category_desc=None, avg_grade=None, start_latlng=None, end_latlng=None, elev_difference=None, distance=None, points=None):  # noqa: E501
        """ExplorerSegment - a model defined in Swagger"""  # noqa: E501

        self._id = None
        self._name = None
        self._climb_category = None
        self._climb_category_desc = None
        self._avg_grade = None
        self._start_latlng = None
        self._end_latlng = None
        self._elev_difference = None
        self._distance = None
        self._points = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if name is not None:
            self.name = name
        if climb_category is not None:
            self.climb_category = climb_category
        if climb_category_desc is not None:
            self.climb_category_desc = climb_category_desc
        if avg_grade is not None:
            self.avg_grade = avg_grade
        if start_latlng is not None:
            self.start_latlng = start_latlng
        if end_latlng is not None:
            self.end_latlng = end_latlng
        if elev_difference is not None:
            self.elev_difference = elev_difference
        if distance is not None:
            self.distance = distance
        if points is not None:
            self.points = points

    @property
    def id(self):
        """Gets the id of this ExplorerSegment.  # noqa: E501

        The unique identifier of this segment  # noqa: E501

        :return: The id of this ExplorerSegment.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this ExplorerSegment.

        The unique identifier of this segment  # noqa: E501

        :param id: The id of this ExplorerSegment.  # noqa: E501
        :type: int
        """

        self._id = id

    @property
    def name(self):
        """Gets the name of this ExplorerSegment.  # noqa: E501

        The name of this segment  # noqa: E501

        :return: The name of this ExplorerSegment.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this ExplorerSegment.

        The name of this segment  # noqa: E501

        :param name: The name of this ExplorerSegment.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def climb_category(self):
        """Gets the climb_category of this ExplorerSegment.  # noqa: E501

        The category of the climb  # noqa: E501

        :return: The climb_category of this ExplorerSegment.  # noqa: E501
        :rtype: int
        """
        return self._climb_category

    @climb_category.setter
    def climb_category(self, climb_category):
        """Sets the climb_category of this ExplorerSegment.

        The category of the climb  # noqa: E501

        :param climb_category: The climb_category of this ExplorerSegment.  # noqa: E501
        :type: int
        """
        if climb_category is not None and climb_category > 5:  # noqa: E501
            raise ValueError("Invalid value for `climb_category`, must be a value less than or equal to `5`")  # noqa: E501
        if climb_category is not None and climb_category < 0:  # noqa: E501
            raise ValueError("Invalid value for `climb_category`, must be a value greater than or equal to `0`")  # noqa: E501

        self._climb_category = climb_category

    @property
    def climb_category_desc(self):
        """Gets the climb_category_desc of this ExplorerSegment.  # noqa: E501

        The description for the category of the climb  # noqa: E501

        :return: The climb_category_desc of this ExplorerSegment.  # noqa: E501
        :rtype: str
        """
        return self._climb_category_desc

    @climb_category_desc.setter
    def climb_category_desc(self, climb_category_desc):
        """Sets the climb_category_desc of this ExplorerSegment.

        The description for the category of the climb  # noqa: E501

        :param climb_category_desc: The climb_category_desc of this ExplorerSegment.  # noqa: E501
        :type: str
        """
        allowed_values = ["NC", "4", "3", "2", "1", "HC"]  # noqa: E501
        if climb_category_desc not in allowed_values:
            raise ValueError(
                "Invalid value for `climb_category_desc` ({0}), must be one of {1}"  # noqa: E501
                .format(climb_category_desc, allowed_values)
            )

        self._climb_category_desc = climb_category_desc

    @property
    def avg_grade(self):
        """Gets the avg_grade of this ExplorerSegment.  # noqa: E501

        The segment's average grade, in percents  # noqa: E501

        :return: The avg_grade of this ExplorerSegment.  # noqa: E501
        :rtype: float
        """
        return self._avg_grade

    @avg_grade.setter
    def avg_grade(self, avg_grade):
        """Sets the avg_grade of this ExplorerSegment.

        The segment's average grade, in percents  # noqa: E501

        :param avg_grade: The avg_grade of this ExplorerSegment.  # noqa: E501
        :type: float
        """

        self._avg_grade = avg_grade

    @property
    def start_latlng(self):
        """Gets the start_latlng of this ExplorerSegment.  # noqa: E501


        :return: The start_latlng of this ExplorerSegment.  # noqa: E501
        :rtype: LatLng
        """
        return self._start_latlng

    @start_latlng.setter
    def start_latlng(self, start_latlng):
        """Sets the start_latlng of this ExplorerSegment.


        :param start_latlng: The start_latlng of this ExplorerSegment.  # noqa: E501
        :type: LatLng
        """

        self._start_latlng = start_latlng

    @property
    def end_latlng(self):
        """Gets the end_latlng of this ExplorerSegment.  # noqa: E501


        :return: The end_latlng of this ExplorerSegment.  # noqa: E501
        :rtype: LatLng
        """
        return self._end_latlng

    @end_latlng.setter
    def end_latlng(self, end_latlng):
        """Sets the end_latlng of this ExplorerSegment.


        :param end_latlng: The end_latlng of this ExplorerSegment.  # noqa: E501
        :type: LatLng
        """

        self._end_latlng = end_latlng

    @property
    def elev_difference(self):
        """Gets the elev_difference of this ExplorerSegment.  # noqa: E501

        The segments's evelation difference, in meters  # noqa: E501

        :return: The elev_difference of this ExplorerSegment.  # noqa: E501
        :rtype: float
        """
        return self._elev_difference

    @elev_difference.setter
    def elev_difference(self, elev_difference):
        """Sets the elev_difference of this ExplorerSegment.

        The segments's evelation difference, in meters  # noqa: E501

        :param elev_difference: The elev_difference of this ExplorerSegment.  # noqa: E501
        :type: float
        """

        self._elev_difference = elev_difference

    @property
    def distance(self):
        """Gets the distance of this ExplorerSegment.  # noqa: E501

        The segment's distance, in meters  # noqa: E501

        :return: The distance of this ExplorerSegment.  # noqa: E501
        :rtype: float
        """
        return self._distance

    @distance.setter
    def distance(self, distance):
        """Sets the distance of this ExplorerSegment.

        The segment's distance, in meters  # noqa: E501

        :param distance: The distance of this ExplorerSegment.  # noqa: E501
        :type: float
        """

        self._distance = distance

    @property
    def points(self):
        """Gets the points of this ExplorerSegment.  # noqa: E501

        The polyline of the segment  # noqa: E501

        :return: The points of this ExplorerSegment.  # noqa: E501
        :rtype: str
        """
        return self._points

    @points.setter
    def points(self, points):
        """Sets the points of this ExplorerSegment.

        The polyline of the segment  # noqa: E501

        :param points: The points of this ExplorerSegment.  # noqa: E501
        :type: str
        """

        self._points = points

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ExplorerSegment, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ExplorerSegment):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Strava API v3

    Strava API  # noqa: E501

    OpenAPI spec version: 3.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from swagger_client.models.base_stream import BaseStream  # noqa: F401,E501


class SmoothGradeStream(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'original_size': 'int',
        'resolution': 'str',
        'series_type': 'str',
        'data': 'list[float]'
    }

    attribute_map = {
        'original_size': 'original_size',
        'resolution': 'resolution',
        'series_type': 'series_type',
        'data': 'data'
    }

    def __init__(self, original_size=None, resolution=None, series_type=None, data=None):  # noqa: E501
        """SmoothGradeStream - a model defined in Swagger"""  # noqa: E501

        self._original_size = None
        self._resolution = None
        self._series_type = None
        self._data = None
        self.discriminator = None

        if original_size is not None:
            self.original_size = original_size
        if resolution is not None:
            self.resolution = resolution
        if series_type is not None:
            self.series_type = series_type
        if data is not None:
            self.data = data

    @property
    def original_size(self):
        """Gets the original_size of this SmoothGradeStream.  # noqa: E501

        The number of data points in this stream  # noqa: E501

        :return: The original_size of this SmoothGradeStream.  # noqa: E501
        :rtype: int
        """
        return self._original_size

    @original_size.setter
    def original_size(self, original_size):
        """Sets the original_size of this SmoothGradeStream.

        The number of data points in this stream  # noqa: E501

        :param original_size: The original_size of this SmoothGradeStream.  # noqa: E501
        :type: int
        """

        self._original_size = original_size

    @property
    def resolution(self):
        """Gets the resolution of this SmoothGradeStream.  # noqa: E501

        The level of detail (sampling) in which this stream was returned  # noqa: E501

        :return: The resolution of this SmoothGradeStream.  # noqa: E501
        :rtype: str
        """
        return self._resolution

    @resolution.setter
    def resolution(self, resolution):
        """Sets the resolution of this SmoothGradeStream.

        The level of detail (sampling) in which this stream was returned  # noqa: E501

        :param resolution: The resolution of this SmoothGradeStream.  # noqa: E501
        :type: str
        """
        allowed_values = ["low", "medium", "high"]  # noqa: E501
        if resolution not in allowed_values:
            raise ValueError(
                "Invalid value for `resolution` ({0}), must be one of {1}"  # noqa: E501
                .format(resolution, allowed_values)
            )

        self._resolution = resolution

    @property
    def series_type(self):
        """Gets the series_type of this SmoothGradeStream.  # noqa: E501

        The base series used in the case the stream was downsampled  # noqa: E501

        :return: The series_type of this SmoothGradeStream.  # noqa: E501
        :rtype: str
        """
        return self._series_type

    @series_type.setter
    def series_type(self, series_type):
        """Sets the series_type of this SmoothGradeStream.

        The base series used in the case the stream was downsampled  # noqa: E501

        :param series_type: The series_type of this SmoothGradeStream.  # noqa: E501
        :type: str
        """
        allowed_values = ["distance", "time"]  # noqa: E501
        if series_type not in allowed_values:
            raise ValueError(
                "Invalid value for `series_type` ({0}), must be one of {1}"  # noqa: E501
                .format(series_type, allowed_values)
            )

        self._series_type = series_type

    @property
    def data(self):
        """Gets the data of this SmoothGradeStream.  # noqa: E501

        The sequence of grade values for this stream, as percents of a grade  # noqa: E501

        :return: The data of this SmoothGradeStream.  # noqa: E501
        :rtype: list[float]
        """
        return self._data

    @data.setter
    def data(self, data):
        """Sets the data of this SmoothGradeStream.

        The sequence of grade values for this stream, as percents of a grade  # noqa: E501

        :param data: The data of this SmoothGradeStream.  # noqa: E501
        :type: list[float]
        """

        self._data = data

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(SmoothGradeStream, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SmoothGradeStream):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Strava API v3

    Strava API  # noqa: E501

    OpenAPI spec version: 3.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class SummaryGear(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'str',
        'resource_state': 'int',
        'primary': 'bool',
        'name': 'str',
        'distance': 'float'
    }

    attribute_map = {
        'id': 'id',
        'resource_state': 'resource_state',
        'primary': 'primary',
        'name': 'name',
        'distance': 'distance'
    }

    def __init__(self, id=None, resource_state=None, primary=None, name=None, distance=None):  # noqa: E501
        """SummaryGear - a model defined in Swagger"""  # noqa: E501

        self._id = None
        self._resource_state = None
        self._primary = None
        self._name = None
        self._distance = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if resource_state is not None:
            self.resource_state = resource_state
        if primary is not None:
            self.primary = primary
        if name is not None:
            self.name = name
        if distance is not None:
            self.distance = distance

    @property
    def id(self):
        """Gets the id of this SummaryGear.  # noqa: E501

        The gear's unique identifier.  # noqa: E501

        :return: The id of this SummaryGear.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this SummaryGear.

        The gear's unique identifier.  # noqa: E501

        :param id: The id of this SummaryGear.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def resource_state(self):
        """Gets the resource_state of this SummaryGear.  # noqa: E501

        Resource state, indicates level of detail. Possible values: 2 -> \"summary\", 3 -> \"detail\"  # noqa: E501

        :return: The resource_state of this SummaryGear.  # noqa: E501
        :rtype: int
        """
        return self._resource_state

    @resource_state.setter
    def resource_state(self, resource_state):
        """Sets the resource_state of this SummaryGear.

        Resource state, indicates level of detail. Possible values: 2 -> \"summary\", 3 -> \"detail\"  # noqa: E501

        :param resource_state: The resource_state of this SummaryGear.  # noqa: E501
        :type: int
        """

        self._resource_state = resource_state

    @property
    def primary(self):
        """Gets the primary of this SummaryGear.  # noqa: E501

        Whether this gear's is the owner's default one.  # noqa: E501

        :return: The primary of this SummaryGear.  # noqa: E501
        :rtype: bool
        """
        return self._primary

    @primary.setter
    def primary(self, primary):
        """Sets the primary of this SummaryGear.

        Whether this gear's is the owner's default one.  # noqa: E501

        :param primary: The primary of this SummaryGear.  # noqa: E501
        :type: bool
        """

        self._primary = primary

    @property
    def name(self):
        """Gets the name of this SummaryGear.  # noqa: E501

        The gear's name.  # noqa: E501

        :return: The name of this SummaryGear.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this SummaryGear.

        The gear's name.  # noqa: E501

        :param name: The name of this SummaryGear.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def distance(self):
        """Gets the distance of this SummaryGear.  # noqa: E501

        The distance logged with this gear.  # noqa: E501

        :return: The distance of this SummaryGear.  # noqa: E501
        :rtype: float
        """
        return self._distance

    @distance.setter
    def distance(self, distance):
        """Sets the distance of this SummaryGear.

        The distance logged with this gear.  # noqa: E501

        :param distance: The distance of this SummaryGear.  # noqa: E501
        :type: float
        """

        self._distance = distance

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(SummaryGear, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SummaryGear):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



import swagger_client
from swagger_client.rest import ApiException
import maya
import os
import json
import datetime
import pandas as pd
import glob
import logging
import datetime
from __version__ import __version__

logger = logging.getLogger(__name__)


class StravaIO():

    def __init__(self, access_token=None):
        if access_token is None:
            access_token = os.getenv('STRAVA_ACCESS_TOKEN')
        self.configuration = swagger_client.Configuration()
        self.configuration.access_token = access_token
        self._api_client = swagger_client.ApiClient(self.configuration)
        self.athletes_api = swagger_client.AthletesApi(self._api_client)
        self.activities_api = swagger_client.ActivitiesApi(self._api_client)
        self.streams_api = swagger_client.StreamsApi(self._api_client)

    def get_logged_in_athlete(self):
        """Get logged in athlete
        
        Returns
        -------
        athlete: Athlete object
        """

        try:
            rv = Athlete(self.athletes_api.get_logged_in_athlete())
        except ApiException as e:
            logger.error(f""""
            Error in strava_swagger_client.AthletesApi! 
            STRAVA_ACCESS_TOKEN is likely out of date!
            Check the https://github.com/sladkovm/strava-oauth for help.
            Returning None.
            Original Error:
            {e}""")
            rv = None
        return rv 

    def local_athletes(self):
        """List local athletes
        
        Returns
        -------
        athletes: generator of JSON friendly dicts
        """
        for f_name in glob.glob(os.path.join(dir_stravadata(), 'athlete*.json')):
            with open(f_name) as f:
                yield json.load(f)


    def get_activity_by_id(self, id):
        """Get activity by ID
        
        Returns
        -------
        activity: Activity ojbect
        """
        return Activity(self.activities_api.get_activity_by_id(id))

    def get_logged_in_athlete_activities(self, after=0, list_activities=None):
        """List all activities after a given date
        
        Parameters
        ----------
        after: int, str or datetime object
            If integer, the time since epoch is assumed
            If str, the maya.parse() compatible date string is expected e.g. iso8601 or 2018-01-01 or 20180101
            If datetime, the datetime object is expected

        Returns
        -------
        list_activities: list
            List of SummaryActivity objects
        """
        
        list_activities = []
        after = date_to_epoch(after)
        _fetched = self.activities_api.get_logged_in_athlete_activities(after=after)
        if len(_fetched) > 0:
            print(f"Fetched {len(_fetched)}, the latests is on {_fetched[-1].start_date}")
            list_activities.extend(_fetched)
            if len(_fetched) == 30:
                last_after = list_activities[-1].start_date
                return self.get_logged_in_athlete_activities(after=last_after, list_activities=list_activities)
        else:
            print("empty list")
        
        return list_activities
        


    def local_activities(self, athlete_id):
        """List local activities
        
        Parameters
        ----------
        athlete_id: int

        Returns
        -------
        activities: generator of JSON friendly dicts
        """
        dir_activities = os.path.join(dir_stravadata(), f"activities_{athlete_id}")
        for f_name in glob.glob(os.path.join(dir_activities, '*.json')):
            with open(f_name) as f:
                yield json.load(f)


    def local_streams(self, athlete_id):
        """List local streams
        
        Parameters
        ----------
        athlete_id: int

        Returns
        -------
        streams: generator of dataframes
        """
        dir_streams = os.path.join(dir_stravadata(), f"streams_{athlete_id}")
        for f_name in glob.glob(os.path.join(dir_streams, '*.parquet')):
            yield pd.read_parquet(f_name)


    def get_activity_streams(self, id, athlete_id, local=True):
        """Get activity streams by ID
        
        Parameters
        ----------
        id: int
            activity_id
        athlete_id: int
            athlete_id
        local: bool (default=True)
            if the streams is already storred, return the local version

        Returns
        -------
        streams: Streams ojbect (remote) or pd.Dataframe (local)
        """
        if local:
            dir_streams = os.path.join(dir_stravadata(), f"streams_{athlete_id}")
            f_name = f"streams_{id}.parquet"
            f_path = os.path.join(dir_streams, f_name)
            if f_path in glob.glob(f_path):
                return pd.read_parquet(f_path)
        keys = ['time', 'distance', 'latlng', 'altitude', 'velocity_smooth',
        'heartrate', 'cadence', 'watts', 'temp', 'moving', 'grade_smooth']
        api_response = self.streams_api.get_activity_streams(id, keys, key_by_type=True)
        return Streams(api_response, id, athlete_id)


class Athlete():

    def __init__(self, api_response):
        """
        Parameters
        ----------
        api_response: swagger_client.get...() object
            e.g. athletes_api.get_logged_in_athlete()
        """
        self.api_response = api_response
        self.id = self.api_response.id

    def __str__(self):
        return self._stringify()

    def __repr__(self):
        return self._stringify()

    def to_dict(self):
        _dict = self.api_response.to_dict()
        _dict = convert_datetime_to_iso8601(_dict)
        return _dict

    def store_locally(self):
        strava_dir = dir_stravadata()
        f_name = f"athlete_{self.api_response.id}.json"
        with open(os.path.join(strava_dir, f_name), 'w') as fp:
            json.dump(self.to_dict(), fp)

    def _stringify(self):
        return json.dumps(self.to_dict(), indent=2)

class Activity():

    def __init__(self, api_response, client=None):
        self.api_response = api_response
        self.athlete_id = self.api_response.athlete.id
        self.id = self.api_response.id
        if client:
            self.streams_api = client.streams_api
        else:
            client = None

    def __repr__(self):
        return f"Activity: {self.id}, Date: {self.api_response.start_date}, Name: {self.api_response.name}"

    def to_dict(self):
        _dict = self.api_response.to_dict()
        _dict = convert_datetime_to_iso8601(_dict)
        return _dict

    def store_locally(self):
        strava_dir = dir_stravadata()
        athlete_id = self.api_response.athlete.id
        activities_dir = os.path.join(strava_dir, f"activities_{athlete_id}")
        if not os.path.exists(activities_dir):
            os.mkdir(activities_dir)
        f_name = f"activity_{self.api_response.id}.json"
        with open(os.path.join(activities_dir, f_name), 'w') as fp:
            json.dump(self.to_dict(), fp)



class Streams():

    ACCEPTED_KEYS = ['time', 'distance', 'altitude', 'velocity_smooth', 'heartrate', 'cadence', 'watts', 'temp', 'moving', 'grade_smooth', 'lat', 'lng']

    def __init__(self, api_response, activity_id, athlete_id):
        self.api_response = api_response
        self.activity_id = activity_id
        self.athlete_id = athlete_id

    def __repr__(self):
        return f"""Streams for {self.activity_id}\nKeys: {list(self.to_dict().keys())}\nAccess: obj.key or obj.to_dict() to load into a pd.DataFrame()"""

    def to_dict(self):
        _dict = self.api_response.to_dict()
        r = {}
        for k, v in _dict.items():
            if v is not None:
                r.update({k: v['data']})
        if r.get('latlng', None):
            latlng = r.pop('latlng')
            _r = list(zip(*latlng))
            r.update({'lat': list(_r[0])})
            r.update({'lng': list(_r[1])}) 
        return r

    def store_locally(self):
        _df = pd.DataFrame(self.to_dict())
        strava_dir = dir_stravadata()
        streams_dir = os.path.join(strava_dir, f"streams_{self.athlete_id}")
        if not os.path.exists(streams_dir):
            os.mkdir(streams_dir)
        f_name = f"streams_{self.activity_id}.parquet"
        _df.to_parquet(os.path.join(streams_dir, f_name))

    @property
    def time(self):
        return self._get_stream_by_name('time')

    @property
    def distance(self):
        return self._get_stream_by_name('distance')

    @property
    def altitude(self):
        return self._get_stream_by_name('altitude')

    @property
    def velocity_smooth(self):
        return self._get_stream_by_name('velocity_smooth')

    @property
    def heartrate(self):
        return self._get_stream_by_name('heartrate')

    @property
    def cadence(self):
        return self._get_stream_by_name('cadence')

    @property
    def watts(self):
        return self._get_stream_by_name('watts')

    @property
    def grade_smooth(self):
        return self._get_stream_by_name('grade_smooth')

    @property
    def moving(self):
        return self._get_stream_by_name('moving')
    
    @property
    def lat(self):
        return self._get_stream_by_name('lat')

    @property
    def lng(self):
        return self._get_stream_by_name('lng')


    def _get_stream_by_name(self, key):
        
        if key not in self.ACCEPTED_KEYS:
            raise KeyError(f"key must be one of {self.ACCEPTED_KEYS}")
        
        try:
            rv = self.to_dict()[key]
        except KeyError:
            logger.warning(f"Stream does not contain {key}")
            rv = None
        return rv





def convert_datetime_to_iso8601(d):
    for k, v in d.items():
        if isinstance(v, dict):
            convert_datetime_to_iso8601(v)
        elif isinstance(v, list):
            for i in v:
                if isinstance(i, dict):
                    convert_datetime_to_iso8601(i)
        else:
            if isinstance(v, datetime.datetime):
                d[k] = maya.parse(v).iso8601()
    return d


def dir_stravadata():
    home_dir = os.path.expanduser('~')
    strava_dir = os.path.join(home_dir, '.stravadata')
    if not os.path.exists(strava_dir):
        os.mkdir(strava_dir)
    return strava_dir


def date_to_epoch(date):
    """Convert a date to epoch representation"""
    rv = None
    if isinstance(date, int):
        rv = date
    if isinstance(date, datetime.datetime):
        _ = maya.parse(date)
        rv = _.epoch
    if isinstance(date, str):
        _ = maya.when(date)
        rv = _.epoch
    if rv is None:
        raise TypeError('date must be epoch int, datetime obj or the string')
    return rv